/* This file is part of GEGL.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Copyright 2013 Michael Henning <drawoc@darkrefraction.com>
 */

#ifndef __GEGL_BUFFER_ITERATOR_PRIVATE_H__
#define __GEGL_BUFFER_ITERATOR_PRIVATE_H__

G_STATIC_ASSERT (GEGL_BUFFER_READWRITE == 0x3);

#define GEGL_ITERATOR_INCOMPATIBLE (1 << 2)
#define GEGL_ITERATOR_NO_NOTIFY    (1 << 3)

#endif
